DebouncingTextController class

A drop-in replacement for SearchController with debounce Duration.

Inheritance

Constructors

DebouncingTextController({String? text, Duration duration = const Duration(milliseconds: 300)})
Creates a DebouncingTextController with some debounce duration.

Properties

duration Duration
Duration of each _debounceTimer.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
lastChangeDateTime DateTime?
DateTime of the start of the last _debounceTimer.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Simpler way to get text.
no setter
textEditingController TextEditingController
Original TextEditingController just in case.
no setter
untilNotify Duration?
Duration until notifyListeners is called.
no setterinherited
value TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
change(VoidCallback specificChangeMethod) → void
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited