DebouncingChangeNotifier class
A debouncing change notifier.
- Inheritance
-
- Object
- ChangeNotifier
- DebouncingChangeNotifier
Constructors
- DebouncingChangeNotifier({Duration duration = const Duration(milliseconds: 300)})
-
Creates a DebouncingChangeNotifier with some debounce
duration.
Properties
- duration ↔ Duration
-
Duration of each
_debounceTimer.latefinalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- lastChangeDateTime → DateTime?
-
DateTime of the start of the last
_debounceTimer.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- untilNotify → Duration?
-
Duration until notifyListeners is called.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
change(
VoidCallback specificChangeMethod) → void -
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited